@@ -45,7 +45,7 @@ class UserSettingsModifyParameters(UserSettingsDisplayParameters):
 class UserDeleteParameters(view.Parameters):
     def register(self):
         self.optional("users", list, [ ])
-    
+
 
 
 class UserListing(view.View):
@@ -56,23 +56,25 @@ class UserListing(view.View):
 
     def hasPermission(self, perm, permlist):
         return perm in permlist
-        
+
     def render(self):
+        self.dataset["backend_can_create"] = self.env.auth.canCreateUser()
+        self.dataset["backend_can_delete"] = self.env.auth.canDeleteUser()
         self.dataset["add_form_hiddens"] = [("view", "user_add_form")]
         self.dataset["permissions"] = User.ALL_PERMISSIONS
         self.dataset["can_set_password"] = self.env.auth and self.env.auth.canSetPassword()
         self.dataset["users"] = [ ]
 
-        logins = self.env.db.getUserLogins()
+        logins = self.env.auth.getUserLogins()
         logins.sort()
         for login in logins:
             permissions = self.env.db.getPermissions(login)
-            
+
             tmp = { }
             tmp["login"] = login
             tmp["settings_link"] = utils.create_link("user_settings_display", { "login": login, "origin": self.view_name })
             tmp["permissions"] = map(lambda perm: self.hasPermission(perm, permissions), User.ALL_PERMISSIONS)
-            
+
             self.dataset["users"].append(tmp)
 
 
@@ -85,18 +87,19 @@ class UserAddForm(view.View):
 
     def render(self, errmsg=None):
         self.dataset["user.login"] = None
+        self.dataset["user.origin"] = "user_listing"
 
         self.dataset["user.permissions"] = []
         for perm in User.ALL_PERMISSIONS:
             self.dataset["user.permissions"] += [(perm, False)]
-        
+
         self.dataset["errmsg"] = errmsg
         self.dataset["can_manage_user"] = self.user.has(User.PERM_USER_MANAGEMENT)
         self.dataset["can_change_password"] = self.env.auth.canSetPassword()
         self.dataset["ask_current_password"] = False
         self.dataset["available_languages"] = localization.getLanguagesAndIdentifiers()
         self.dataset["user.language"] = localization._DEFAULT_LANGUAGE
-        
+
         self.dataset["hiddens"] = [ ("view", "user_add") ]
         self.dataset["properties"] = [ utils.text_property("Login", "login") ]
         if self.env.auth.canSetPassword():
@@ -106,7 +109,6 @@ class UserAddForm(view.View):
             self.dataset["properties"].append(utils.boolean_property(perm, perm))
 
 
-
 class UserDelete(UserListing):
     view_name = "user_delete"
     view_parameters = UserDeleteParameters
@@ -114,7 +116,7 @@ class UserDelete(UserListing):
     def render(self):
         for user in self.parameters["users"]:
             self.env.db.deleteUser(user)
-        
+
         self.parameters.clear()
         UserListing.render(self)
 
@@ -129,7 +131,7 @@ class UserSettingsDisplay(view.View):
     def render(self):
         login = self.parameters.get("login", self.user.login)
 
-        if login != self.user.login and not self.user.has(User.PERM_USER_MANAGEMENT):            
+        if login != self.user.login and not self.user.has(User.PERM_USER_MANAGEMENT):
             raise Error.PrewikkaUserError("Permission Denied", "Access denied to other users settings", log=Log.WARNING)
 
         self.dataset["available_languages"] = localization.getLanguagesAndIdentifiers()
@@ -143,7 +145,7 @@ class UserSettingsDisplay(view.View):
 
         if self.parameters.has_key("origin"):
             self.dataset["user.origin"] = self.parameters["origin"]
-        
+
         permissions = self.env.db.getPermissions(login)
         for perm in User.ALL_PERMISSIONS:
             self.dataset["user.permissions"].append((perm, perm in permissions))
@@ -157,28 +159,28 @@ class UserSettingsModify(UserSettingsDisplay):
 
     def render(self):
         login = self.parameters.get("login", self.user.login)
-        
-        if login != self.user.login and not self.user.has(User.PERM_USER_MANAGEMENT):            
+
+        if login != self.user.login and not self.user.has(User.PERM_USER_MANAGEMENT):
             raise Error.PrewikkaUserError("Permission Denied", "Cannot modify other users settings", log=Log.WARNING)
-        
+
         if self.user.has(User.PERM_USER_MANAGEMENT):
             self.env.db.setPermissions(login, self.parameters["permissions"])
             if login == self.user.login:
                 self.user.permissions = self.parameters["permissions"]
-        
+
         lang = self.parameters["language"]
         if not lang in localization.getLanguagesIdentifiers():
             raise Error.PrewikkaUserError("Invalid Language", "Specified language does not exist", log=Log.WARNING)
-        
+
         if login == self.user.login:
             self.user.setLanguage(lang)
-        
+
         self.env.db.setLanguage(login, lang)
-                    
+
         if self.parameters.has_key("password_new") and self.parameters.has_key("password_new_confirmation"):
-            if self.parameters.has_key("password_current"):
+            if login == self.user.login:
                 try:
-                    self.env.auth.checkPassword(login, self.parameters["password_current"])
+                    self.env.auth.checkPassword(login, self.parameters.get("password_current", ""))
                 except Auth.AuthError, e:
                     raise Error.PrewikkaUserError("Password Error", "Invalid Password specified")
 
@@ -189,11 +191,11 @@ class UserSettingsModify(UserSettingsDisplay):
 
         origin = self.parameters.get("origin", None)
         self.parameters.clear()
-        
+
         if origin:
             self.parameters["origin"] = origin
         self.parameters["login"] = login
-        
+
         return UserSettingsDisplay.render(self)
 
 class UserSettingsAdd(UserSettingsModify, UserAddForm):
