@@ -22,8 +22,9 @@ import re
 import time
 import struct
 import socket
+import urllib
 
-from prewikka import view, User, utils
+from prewikka import view, User, utils, resolve
 
 
 def getUriCriteria(parameters):
@@ -423,15 +424,17 @@ class MessageSummary(Table):
         if not node:
             return
 
-        self.newTableEntry(_("Node name"), node["name"])
         self.newTableEntry(_("Node location"), node["location"])
 
         addr_list = None
+        node_name = None
         for addr in node["address"]:
             address = addr["address"]
             if not address:
                 continue
 
+            node_name = resolve.AddressResolve(address)
+
             if addr_list:
                 addr_list += "<br/>"
             else:
@@ -442,6 +445,12 @@ class MessageSummary(Table):
             else:
                 addr_list += address
 
+        if node["name"]:
+            self.newTableEntry(_("Node name"), node["name"])
+
+        elif node_name:
+            self.newTableEntry(_("Node name (resolved)"), node_name)
+
         self.newTableEntry(_("Node address"), addr_list)
 
     def buildAnalyzer(self, analyzer):
@@ -647,17 +656,22 @@ class AlertSummary(TcpIpOptions, MessageSummary, view.View):
         for analyzerid in calist.keys():
 
             content = ""
+            missing = 0
             for ident in calist[analyzerid]:
                 criteria = "alert.analyzer.analyzerid = '%s' && alert.messageid = '%s'" % (analyzerid, ident)
 
                 results = self.env.idmef_db.getAlertIdents(criteria)
                 if len(results) == 0:
-                    content += "<li>" + _("Invalid 'analyzerid:messageid' pair, '%(analyzerid):%(messageid)'") % { "analyzerid": analyzerid, "messageid": messageid } + "</li>"
+                    missing += 1
+                    #content += "<li>" + _("Invalid 'analyzerid:messageid' pair, '%(analyzerid):%(messageid)'") % { "analyzerid": analyzerid, "messageid": ident } + "</li>"
                 else:
                     alert = self.env.idmef_db.getAlert(results[0], htmlsafe=True)
                     link = utils.create_link("alert_summary", { "origin": self.parameters["origin"], "ident": results[0] })
                     content += "<li><a href=\"%s\">%s</a></li>" % (link, alert["classification.text"])
 
+            if missing > 0:
+                content += "<li>" + (_("%d linked alerts missing (probably deleted)") % missing) + "</li>"
+
             self.newTableCol(idx, "<ul style='padding: 0px; margin: 0px 0px 0px 10px;'>%s</ul>" % content)
             self.buildAnalyzer(alert["analyzer(-1)"])
             self.newTableRow()
@@ -689,7 +703,7 @@ class AlertSummary(TcpIpOptions, MessageSummary, view.View):
 
         self.beginSection(_("Tool Alert"))
         self.beginTable()
-        self.newTableEntry(_("Name"), ca["alert.tool_alert.name"])
+        self.newTableEntry(_("Name"), ta["alert.tool_alert.name"])
         self.endTable()
 
         self.beginTable()
@@ -719,11 +733,11 @@ class AlertSummary(TcpIpOptions, MessageSummary, view.View):
         for reference in alert["classification.reference"]:
             self.newTableCol(index, reference["origin"])
             if reference["origin"] in ("user-specific", "vendor-specific"):
-                urlstr="&url=%s" % reference["url"]
+                urlstr="&url=" + urllib.quote(reference["url"], safe="")
             else:
                 urlstr=""
 
-            self.newTableCol(index, self.getUrlLink(reference["name"], "http://www.prelude-ids.com/reference_details.php?origin=%s&name=%s%s" % (reference["origin"], reference["name"], urlstr)))
+            self.newTableCol(index, self.getUrlLink(reference["name"], "http://www.prelude-ids.com/reference_details.php?origin=%s&name=%s%s" % (urllib.quote(reference["origin"]), urllib.quote(reference["name"]), urlstr)))
             self.newTableCol(index, reference["meaning"])
             index += 1
 
@@ -891,6 +905,26 @@ class AlertSummary(TcpIpOptions, MessageSummary, view.View):
             port = str(service["port"])
             self.newTableEntry(_("Port"), self.getUrlLink(port, "https://www.prelude-ids.com/port_details.php?port=%s" % port))
 
+        portlist = service["portlist"]
+        if portlist:
+            out = ""
+            for port in portlist.replace(" ", "").split(","):
+                if len(out) > 0:
+                    out += ", "
+
+                if port.find("-") != -1:
+                    left, right = port.split("-")
+                    out += self.getUrlLink(left, "https://www.prelude-ids.com/port_details.php?port=%s" % left)
+                    out += " - "
+                    out += self.getUrlLink(right, "https://www.prelude-ids.com/port_details.php?port=%s" % right)
+                else:
+                    out += self.getUrlLink(port, "https://www.prelude-ids.com/port_details.php?port=%s" % port)
+
+            self.newTableEntry(_("PortList"), out)
+
+        if service["ip_version"]:
+            self.newTableEntry(_("ip_version"), service["ip_version"])
+
         ipn = service["iana_protocol_number"]
         if ipn and utils.protocol_number_to_name(ipn) != None:
             self.newTableEntry(_("Protocol"), utils.protocol_number_to_name(ipn))
@@ -973,6 +1007,10 @@ class AlertSummary(TcpIpOptions, MessageSummary, view.View):
 
         self.buildTime(alert)
 
+        self.beginTable()
+        self.newTableEntry(_("MessageID"), alert["messageid"])
+        self.endTable()
+
         self.beginTable()
         self.buildClassification(alert)
         self.buildImpact(alert)
